/*
 * Copyright (c) 2004 Center for Comparative and International Studies
 * at the Swiss Federal Institute of Technology Zurich
 * (see http://www.cis.ethz.ch/ for details)
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
 *
 * Please see http://www.gnu.org/copyleft/gpl.txt for the full license text.
 *
 */
package ch.ethz.icr.geosim0;

import uchicago.src.sim.util.Random;

/**
 * Geosim: Geopolitical Simulation Model
 * A model to simulate state formation with endogenous boundaries
 *
 * This model is based on the architecture introduced in Cederman, EMERGENT ACTORS IN WORLD
 * POLITICS. Princeton University Press, 1997. The current model corresponds to the more
 * recent article Cederman, "Modeling the Size of Wars: From Billiard Balls to Sandpiles,"
 * AMERICAN POLITICAL SCIENCE REVIEW 97 (February 2003): 135-150.
 *
 * @author Luc Girardin
 * @author Lars-Erik Cederman
 * @version 3.0
 */
final class Utility {

    /**
     * Bernouilli probability distribution (true with probability p)
     *
     * @param p
     * @return
     */
    public static final boolean bern(final double p) {
        if (p == 0.0)
            return false;
        else if (p == 1.0)
            return true;
        else
            return (Random.uniform.nextDoubleFromTo(0.0, 1.0) < p);
    }

    /**
     * Logistical distance function
     *
     * @param ratio
     * @param sup
     * @param supC
     * @return
     */
    static final double logistic(final double ratio, final double sup, final double supC) {
        if (ratio == 0)
            return 0.0;
        else
            return 1.0 / (1.0 + Math.exp(supC * Math.log(sup / ratio)));
    }

}
